@@ -664,12 +664,21 @@ class File(PathBase):
     def size(self) -> int:
         """ 计算文件大小
         """
-        if self.eixsts():
+        if self.exists():
             total_size = os.path.getsize(str(self))
         else:
             total_size = 0
         return total_size
 
+    def size2(self) -> int:
+        """ 220102周日17:23
+
+        size有点bug，临时写个函数接口
+        这个bug有点莫名其妙，搞不定
+        """
+        total_size = os.path.getsize(str(self))
+        return total_size
+
     # 四、文件操作功能
 
     def absdst(self, dst):
@@ -837,6 +846,12 @@ class XlPath(type(pathlib.Path())):
     def tempdir(cls):
         return cls(tempfile.gettempdir())
 
+    @classmethod
+    def tempfile(cls, suffix="", dir=None):
+        if dir is None:
+            dir = tempfile.gettempdir()
+        return cls(tempfile.mktemp(suffix=suffix, dir=dir))
+
     def start(self, *args, **kwargs):
         """ 使用关联的程序打开p，类似于双击的效果
 
@@ -898,7 +913,7 @@ class XlPath(type(pathlib.Path())):
         """
         pass
 
-    def read_text(self, encoding=None, errors='strict', rich_return: bool = False):
+    def read_text(self, encoding='utf8', errors='strict', rich_return: bool = False):
         bstr = self.read_bytes()
         if not encoding: encoding = get_encoding(bstr)
         s = bstr.decode(encoding=encoding, errors=errors)
@@ -957,9 +972,9 @@ class XlPath(type(pathlib.Path())):
         else:
             return data
 
-    def write_yaml(self, data, encoding='utf8'):
+    def write_yaml(self, data, encoding='utf8', *, sort_keys=False, **kwargs):
         with open(self, 'w', encoding=encoding) as f:
-            yaml.dump(data, f)
+            yaml.dump(data, f, sort_keys=sort_keys, **kwargs)
 
     def read_bib(self, encoding='utf8'):
         import bibtexparser
